@@ -7,6 +7,9 @@ import math
 
 class Distance:
 
+    def __init__(self):
+        pass
+
     @staticmethod
     def checkValidity(a, b, c):
         """
