@@ -1,6 +1,9 @@
 from calculation.distance import Distance
 from calculation.pixel import Pixel
 
+import decimal
+
+
 class Intersection:
 
     def __init__(self, intersection_lineLength, angle_wide):
@@ -172,25 +175,29 @@ class Intersection:
                                      start_lat2, start_lon2, theta2],
                                     )
 
-        intSection1Lat, intSection1Lon, \
-        intSection2Lat, intSection2Lon = self.intersection_decimal_to_float(ops1["lat"],
-                                                                            ops1["lon"],
-                                                                            ops2["lat"],
-                                                                            ops2["lon"])
+        # We check whether any variable is decimal or not,
+        # because the heading calculation in requests from the web can be float,
+        # and the one from the database can be decimal.
+        if isinstance(ops1["lat"], decimal.Decimal):
+            ops1["lat"], ops1["lon"], \
+            ops2["lat"], ops2["lon"] = self.intersection_decimal_to_float(ops1["lat"],
+                                                                                ops1["lon"],
+                                                                                ops2["lat"],
+                                                                                ops2["lon"])
 
         destinationPoint1 = [(start_lat1, start_lon1),
-                             (intSection1Lat, intSection1Lon)]
+                             (ops1["lat"], ops1["lon"])]
 
         destinationPoint2 = [(start_lat2, start_lon2),
-                             (intSection2Lat, intSection2Lon)]
+                             (ops2["lat"], ops2["lon"])]
 
         interSection = self.checkLineIntersection(start_lat1,
                                                   start_lon1,
-                                                  intSection1Lat, intSection1Lon,
+                                                  ops1["lat"], ops1["lon"],
 
                                                   start_lat2,
                                                   start_lon2,
-                                                  intSection2Lat, intSection2Lon)
+                                                  ops2["lat"], ops2["lon"])
 
         return interSection, destinationPoint1, destinationPoint2
 
